==> opensaml-soap-impl-4.3.0-sources.jar: org/opensaml/soap/wstrust/impl/RenewingUnmarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wstrust.impl;


import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.core.xml.schema.XSBooleanValue;
import org.opensaml.soap.wstrust.Renewing;
import org.w3c.dom.Attr;

/**
 * Unmarshaller for the empty wst:Renewing element.
 * 
 */
public class RenewingUnmarshaller extends AbstractWSTrustObjectUnmarshaller {

    /** {@inheritDoc} */
    protected void processAttribute(final XMLObject xmlObject, final Attr attribute) throws UnmarshallingException {
        final Renewing renewing = (Renewing) xmlObject;
        
        if (attribute.getLocalName().equals(Renewing.ALLOW_ATTRIB_NAME)) {
            renewing.setAllow(XSBooleanValue.valueOf(attribute.getValue()));
        } else if (attribute.getLocalName().equals(Renewing.OK_ATTRIB_NAME)) {
            renewing.setOK(XSBooleanValue.valueOf(attribute.getValue()));
        } else {
            super.processAttribute(xmlObject, attribute);
        }
    }

}

==> opensaml-soap-impl-5.1.4-sources.jar: org/opensaml/soap/wstrust/impl/RenewingUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wstrust.impl;


import javax.annotation.Nonnull;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.core.xml.schema.XSBooleanValue;
import org.opensaml.soap.wstrust.Renewing;
import org.w3c.dom.Attr;

/**
 * Unmarshaller for the empty wst:Renewing element.
 * 
 */
public class RenewingUnmarshaller extends AbstractWSTrustObjectUnmarshaller {

    /** {@inheritDoc} */
    protected void processAttribute(@Nonnull final XMLObject xmlObject, @Nonnull final Attr attribute)
            throws UnmarshallingException {
        final Renewing renewing = (Renewing) xmlObject;
        
        if (attribute.getLocalName().equals(Renewing.ALLOW_ATTRIB_NAME)) {
            renewing.setAllow(XSBooleanValue.valueOf(attribute.getValue()));
        } else if (attribute.getLocalName().equals(Renewing.OK_ATTRIB_NAME)) {
            renewing.setOK(XSBooleanValue.valueOf(attribute.getValue()));
        } else {
            super.processAttribute(xmlObject, attribute);
        }
    }

}
